pub struct I2sTxDmaTransfer<'d, Dm, Buf>where
Dm: DriverMode,
Buf: DmaTxBuffer,{ /* private fields */ }Available on crate feature
unstable only.Expand description
A structure representing a DMA transfer.
This structure holds references to the driver instance, DMA buffers, and transfer status.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<'d, Dm, Buf> I2sTxDmaTransfer<'d, Dm, Buf>where
Dm: DriverMode,
Buf: DmaTxBuffer,
impl<'d, Dm, Buf> I2sTxDmaTransfer<'d, Dm, Buf>where
Dm: DriverMode,
Buf: DmaTxBuffer,
Sourceimpl<'d, Buf> I2sTxDmaTransfer<'d, Async, Buf>where
Buf: DmaTxBuffer,
impl<'d, Buf> I2sTxDmaTransfer<'d, Async, Buf>where
Buf: DmaTxBuffer,
Sourcepub async fn wait_async(
self,
) -> (Result<(), DmaError>, I2sTx<'d, Async>, Buf::Final)
pub async fn wait_async( self, ) -> (Result<(), DmaError>, I2sTx<'d, Async>, Buf::Final)
Waits for the transfer to finish and returns the peripheral and buffer.
Sourcepub async fn wait_for_done_async(&mut self) -> Result<(), DmaError>
pub async fn wait_for_done_async(&mut self) -> Result<(), DmaError>
Waits for the transfer to finish.
Sourcepub async fn wait_for_available_async(&mut self) -> Result<(), DmaError>
pub async fn wait_for_available_async(&mut self) -> Result<(), DmaError>
Waits for a condition that might indicate more data is available.